@@ -29,11 +29,11 @@ pub async fn profile(req: Request<Body>) -> Result<Response<Body>, String> {
 	);
 
 	// Retrieve other variables from Libreddit request
-	let sort = param(&path, "sort");
+	let sort = param(&path, "sort").unwrap_or_default();
 	let username = req.param("name").unwrap_or_default();
 
 	// Request user posts/comments from Reddit
-	let posts = Post::fetch(&path, "Comment".to_string()).await;
+	let posts = Post::fetch(&path, "Comment".to_string(), false).await;
 	let url = String::from(req.uri().path_and_query().map_or("", |val| val.as_str()));
 
 	match posts {
@@ -44,8 +44,8 @@ pub async fn profile(req: Request<Body>) -> Result<Response<Body>, String> {
 			template(UserTemplate {
 				user,
 				posts,
-				sort: (sort, param(&path, "t")),
-				ends: (param(&path, "after"), after),
+				sort: (sort, param(&path, "t").unwrap_or_default()),
+				ends: (param(&path, "after").unwrap_or_default(), after),
 				prefs: Preferences::new(req),
 				url,
 			})
@@ -61,27 +61,22 @@ async fn user(name: &str) -> Result<User, String> {
 	let path: String = format!("/user/{}/about.json?raw_json=1", name);
 
 	// Send a request to the url
-	match json(path).await {
-		// If success, receive JSON in response
-		Ok(res) => {
-			// Grab creation date as unix timestamp
-			let created: i64 = res["data"]["created"].as_f64().unwrap_or(0.0).round() as i64;
+	json(path, false).await.map(|res| {
+		// Grab creation date as unix timestamp
+		let created: i64 = res["data"]["created"].as_f64().unwrap_or(0.0).round() as i64;
 
-			// Closure used to parse JSON from Reddit APIs
-			let about = |item| res["data"]["subreddit"][item].as_str().unwrap_or_default().to_string();
+		// Closure used to parse JSON from Reddit APIs
+		let about = |item| res["data"]["subreddit"][item].as_str().unwrap_or_default().to_string();
 
-			// Parse the JSON output into a User struct
-			Ok(User {
-				name: name.to_string(),
-				title: esc!(about("title")),
-				icon: format_url(&about("icon_img")),
-				karma: res["data"]["total_karma"].as_i64().unwrap_or(0),
-				created: OffsetDateTime::from_unix_timestamp(created).format("%b %d '%y"),
-				banner: esc!(about("banner_img")),
-				description: about("public_description"),
-			})
+		// Parse the JSON output into a User struct
+		User {
+			name: name.to_string(),
+			title: esc!(about("title")),
+			icon: format_url(&about("icon_img")),
+			karma: res["data"]["total_karma"].as_i64().unwrap_or(0),
+			created: OffsetDateTime::from_unix_timestamp(created).format("%b %d '%y"),
+			banner: esc!(about("banner_img")),
+			description: about("public_description"),
 		}
-		// If the Reddit API returns an error, exit this function
-		Err(msg) => return Err(msg),
-	}
+	})
 }
